@@ -19,11 +19,23 @@ class Frame:
     frames.
     """
 
-    def __init__(self, type_: int = None, recipient: int = BROADCAST_ADDRESS,
-            message: bytearray = bytearray(),
-            sender: int = ECONET_ADDRESS,
-            sender_type: int = ECONET_TYPE,
-            econet_version: int = ECONET_VERSION, data = None):
+    type_: int = None
+    sender: int = None
+    recipient: int = None
+    sender_type: int = ECONET_TYPE
+    econet_version: int = ECONET_VERSION
+    _data = None
+
+    def __init__(
+        self,
+        type_: int = None,
+        recipient: int = BROADCAST_ADDRESS,
+        message: bytearray = bytearray(),
+        sender: int = ECONET_ADDRESS,
+        sender_type: int = ECONET_TYPE,
+        econet_version: int = ECONET_VERSION,
+        data=None,
+    ):
         """Creates new Frame object.
 
         Keyword arguments:
@@ -53,18 +65,30 @@ class Frame:
         else:
             self.message = message
 
-        self.length = HEADER_SIZE + 1 + len(self.message) + 1 + 1
-
     def __repr__(self) -> str:
-        """Creates readable frame respresentation."""
-        name = self.__class__.__name__
-        module = self.__module__.rsplit('.', maxsplit=1)[-1]
-
-        return f'{module[:-1]}: {name}'
+        """Creates string respresentation of class."""
+        return f"""{self.__class__.__name__}(
+    type = {self.type_},
+    recipient = {self.recipient},
+    message = {self.message},
+    sender = {self.sender},
+    sender_type = {self.sender_type},
+    econet_version = {self.econet_version},
+    data = {self._data}
+)
+""".strip()
 
     def __len__(self) -> int:
-        """Returns frame length."""
-        return len(self.to_bytes())
+        """Returns frame length.
+
+        Structure:
+        HEADER_SIZE bytes
+        + 1 bytes frame type
+        + length of message
+        + 1 byte crc
+        + 1 byte end delimiter
+        """
+        return HEADER_SIZE + 1 + len(self.message) + 1 + 1
 
     def data(self):
         """Gets data parsed from frame."""
@@ -77,14 +101,18 @@ class Frame:
     def header(self) -> bytearray:
         """Gets frame header as bytearray."""
         buffer = bytearray(HEADER_SIZE)
-        util.pack_header(buffer, 0, *[
-            FRAME_START,
-            self.length,
-            self.recipient,
-            self.sender,
-            self.sender_type,
-            self.econet_version
-        ])
+        util.pack_header(
+            buffer,
+            0,
+            *[
+                FRAME_START,
+                len(self),
+                self.recipient,
+                self.sender,
+                self.sender_type,
+                self.econet_version,
+            ],
+        )
 
         return buffer
 
@@ -128,9 +156,3 @@ class Frame:
         message - bytearray message to parse
         """
         raise NotImplementedError()
-
-    def response(self, **args) -> Frame:
-        """Returns instance of Frame
-        for response to request, if needed.
-        """
-        raise NotImplementedError()
