@@ -40,13 +40,13 @@ class FrameWriter:
         if isinstance(frame, Frame):
             self._queue.append(frame)
 
-    def queue_empty(self) -> bool:
-        """Empties write queue."""
+    def queue_is_empty(self) -> bool:
+        """Checks if write queue is empty."""
         return len(self._queue) == 0
 
     async def process_queue(self) -> None:
         """Processes top-most write request from the stack."""
-        if len(self._queue) > 0:
+        if self._queue:
             frame = self._queue.pop(0)
             await self.write(frame)
 
@@ -60,9 +60,10 @@ class FrameWriter:
         await self.writer.drain()
 
     def close(self) -> None:
-        """ Closes StreamWriter. """
+        """Closes StreamWriter."""
         self.writer.close()
 
+
 class FrameReader:
     """Used to read and parse received frames
     using asyncio's StreamReader.
@@ -85,19 +86,19 @@ class FrameReader:
         buffer = await self.reader.read(FrameReader.BUFFER_SIZE)
 
         if len(buffer) >= HEADER_SIZE:
-            header = buffer[ 0 : HEADER_SIZE ]
+            header = buffer[0:HEADER_SIZE]
             [
                 _,
                 length,
                 recipient,
                 sender,
                 sender_type,
-                econet_version
+                econet_version,
             ] = util.unpack_header(header)
 
             if recipient in [ECONET_ADDRESS, BROADCAST_ADDRESS]:
                 # Destination address is econet or broadcast.
-                payload = buffer[HEADER_SIZE : length]
+                payload = buffer[HEADER_SIZE:length]
 
                 if HEADER_SIZE + len(payload) != length:
                     raise LengthError()
@@ -106,13 +107,13 @@ class FrameReader:
                     raise ChecksumError()
 
                 try:
-                    return FrameFactory.get_frame(
-                        type_ = payload[0],
-                        recipient = recipient,
-                        message = payload[1:-2],
-                        sender = sender,
-                        sender_type = sender_type,
-                        econet_version = econet_version
+                    return FrameFactory().get_frame(
+                        type_=payload[0],
+                        recipient=recipient,
+                        message=payload[1:-2],
+                        sender=sender,
+                        sender_type=sender_type,
+                        econet_version=econet_version,
                     )
                 except FrameTypeError:
                     pass
